==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/OpenShiftAPIServerListBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OpenShiftAPIServerListBuilder extends OpenShiftAPIServerListFluentImpl<OpenShiftAPIServerListBuilder> implements VisitableBuilder<OpenShiftAPIServerList,OpenShiftAPIServerListBuilder>{
  public OpenShiftAPIServerListBuilder() {
    this(false);
  }
  public OpenShiftAPIServerListBuilder(Boolean validationEnabled) {
    this(new OpenShiftAPIServerList(), validationEnabled);
  }
  public OpenShiftAPIServerListBuilder(OpenShiftAPIServerListFluent<?> fluent) {
    this(fluent, false);
  }
  public OpenShiftAPIServerListBuilder(OpenShiftAPIServerListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OpenShiftAPIServerList(), validationEnabled);
  }
  public OpenShiftAPIServerListBuilder(OpenShiftAPIServerListFluent<?> fluent,OpenShiftAPIServerList instance) {
    this(fluent, instance, false);
  }
  public OpenShiftAPIServerListBuilder(OpenShiftAPIServerListFluent<?> fluent,OpenShiftAPIServerList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public OpenShiftAPIServerListBuilder(OpenShiftAPIServerList instance) {
    this(instance,false);
  }
  public OpenShiftAPIServerListBuilder(OpenShiftAPIServerList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  OpenShiftAPIServerListFluent<?> fluent;
  Boolean validationEnabled;
  public OpenShiftAPIServerList build() {
    OpenShiftAPIServerList buildable = new OpenShiftAPIServerList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-operator-6.8.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/OpenShiftAPIServerListBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OpenShiftAPIServerListBuilder extends OpenShiftAPIServerListFluent<OpenShiftAPIServerListBuilder> implements VisitableBuilder<OpenShiftAPIServerList,OpenShiftAPIServerListBuilder>{
  public OpenShiftAPIServerListBuilder() {
    this(false);
  }
  public OpenShiftAPIServerListBuilder(Boolean validationEnabled) {
    this(new OpenShiftAPIServerList(), validationEnabled);
  }
  public OpenShiftAPIServerListBuilder(OpenShiftAPIServerListFluent<?> fluent) {
    this(fluent, false);
  }
  public OpenShiftAPIServerListBuilder(OpenShiftAPIServerListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OpenShiftAPIServerList(), validationEnabled);
  }
  public OpenShiftAPIServerListBuilder(OpenShiftAPIServerListFluent<?> fluent,OpenShiftAPIServerList instance) {
    this(fluent, instance, false);
  }
  public OpenShiftAPIServerListBuilder(OpenShiftAPIServerListFluent<?> fluent,OpenShiftAPIServerList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new OpenShiftAPIServerList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public OpenShiftAPIServerListBuilder(OpenShiftAPIServerList instance) {
    this(instance,false);
  }
  public OpenShiftAPIServerListBuilder(OpenShiftAPIServerList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new OpenShiftAPIServerList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  OpenShiftAPIServerListFluent<?> fluent;
  Boolean validationEnabled;
  public OpenShiftAPIServerList build() {
    OpenShiftAPIServerList buildable = new OpenShiftAPIServerList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
